@@ -19,11 +19,11 @@
 module OpscodeAcl
   class UserInviteList < Chef::Knife
     category "OPSCODE HOSTED CHEF ACCESS CONTROL"
-    banner 'knife user invite list'
+    banner "knife user invite list"
 
     def run
       api_endpoint = "association_requests/"
-      invited_users = rest.get_rest(api_endpoint).map { |i| i['username'] }
+      invited_users = rest.get_rest(api_endpoint).map { |i| i["username"] }
       ui.output(invited_users)
     end
   end
